==> iam-0.8.1-sources.jar: software/amazon/awscdk/services/iam/cloudformation/UserToGroupAdditionResource.java <==
package software.amazon.awscdk.services.iam.cloudformation;
/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-addusertogroup.html
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.cloudformation.UserToGroupAdditionResource")
public class UserToGroupAdditionResource extends software.amazon.awscdk.Resource {
    protected UserToGroupAdditionResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.iam.cloudformation.UserToGroupAdditionResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::IAM::UserToGroupAddition``.
     * @param parent the ``cdk.Construct`` this ``UserToGroupAdditionResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``UserToGroupAdditionResource``
     */
    public UserToGroupAdditionResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.iam.cloudformation.UserToGroupAdditionResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
}

==> iam-0.9.0-sources.jar: software/amazon/awscdk/services/iam/cloudformation/UserToGroupAdditionResource.java <==
package software.amazon.awscdk.services.iam.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-addusertogroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:54:34.655Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.cloudformation.UserToGroupAdditionResource")
public class UserToGroupAdditionResource extends software.amazon.awscdk.Resource {
    protected UserToGroupAdditionResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.iam.cloudformation.UserToGroupAdditionResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::IAM::UserToGroupAddition``.
     * @param parent the ``cdk.Construct`` this ``UserToGroupAdditionResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``UserToGroupAdditionResource``
     */
    public UserToGroupAdditionResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.iam.cloudformation.UserToGroupAdditionResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
}
